@@ -15,7 +15,7 @@ from simple_idml.components import (Designmap, Spread, Story, BackingStory,
 from simple_idml.decorators import use_working_copy
 from simple_idml.utils import increment_filename, prefix_content_filename, tree_to_etree_dom
 
-from simple_idml import BACKINGSTORY
+from simple_idml import BACKINGSTORY, SETCONTENT_TAG, IGNORECONTENT_TAG, FORCECONTENT_TAG
 
 STORIES_DIRNAME = "Stories"
 
@@ -378,14 +378,18 @@ class IDMLPackage(zipfile.ZipFile):
                 story.add_content_to_element(element_id, source_node.tail, parent)
             story.synchronize()
 
-        def _import_node(source_node, at=None, element_id=None, story=None):
+        def _import_node(source_node, at=None, element_id=None, story=None, ignorecontent_parent_flag=False):
             element_id = element_id or self.xml_structure.xpath(at)[0].get("Self")
             items = dict(source_node.items())
-            if items:
-                _set_attributes(at, element_id, items)
-            if not (items.get("simpleidml-setcontent") == "false"):
-                _set_content(at, element_id, source_node.text or "", story)
 
+            forcecontent = (items.get(FORCECONTENT_TAG) == "true")
+            if not ignorecontent_parent_flag or forcecontent:
+                if items:
+                    _set_attributes(at, element_id, items)
+                if not (items.get(SETCONTENT_TAG) == "false"):
+                    _set_content(at, element_id, source_node.text or "", story)
+
+            ignorecontent = (items.get(IGNORECONTENT_TAG) == "true") or (ignorecontent_parent_flag and not forcecontent)
             source_node_children = source_node.getchildren()
             if len(source_node_children):
                 source_node_children_tags = [n.tag for n in source_node_children]
@@ -396,18 +400,19 @@ class IDMLPackage(zipfile.ZipFile):
                 # we can call a map() on _import_node().
                 # FIXME: what if source_node.text exists ?
                 if destination_node_children_tags == source_node_children_tags:
-                    map(_import_node, source_node_children,
-                        [self.xml_structure_tree.getpath(c) for c in destination_node.iterchildren()])
+                    map(lambda s, d: _import_node(s, at=d, ignorecontent_parent_flag=ignorecontent),
+                        source_node_children, [self.xml_structure_tree.getpath(c) for c in destination_node.iterchildren()])
                 # Step-by-step iteration.
                 else:
                     destination_node_child = next(destination_node_children, None)
                     for i, source_child in enumerate(source_node_children):
                         # Source and destination match.
                         if destination_node_child is not None and source_child.tag == destination_node_child.tag:
-                            _import_node(source_child, self.xml_structure_tree.getpath(destination_node_child))
+                            _import_node(source_child, at=self.xml_structure_tree.getpath(destination_node_child),
+                                         ignorecontent_parent_flag=ignorecontent)
                             destination_node_child = next(destination_node_children, None)
                         # Source does not match destination. It is added, but only if the tag is mapped to a style.
-                        elif source_child.tag in self.style_mapping.character_style_mapping.keys():
+                        elif not ignorecontent and source_child.tag in self.style_mapping.character_style_mapping.keys():
                             _import_new_node(source_child, at, element_id)
 
         _import_node(source_node, at)
@@ -648,8 +653,8 @@ class IDMLPackage(zipfile.ZipFile):
         at_transform_x, at_transform_y = self.get_elem_translation(at_elem)
 
         only_elem = idml_package.get_spread_elem_by_xpath(only)
-        # <Image> don't store positional information, so we use the parent <Rectangle>.
-        if only_elem.tag == "Image":
+        # <Image> and <EPS> don't store positional informations, so we use the parent <Rectangle>.
+        if only_elem.tag in ["Image", "EPS"]:
             only_elem = only_elem.getparent()
         only_rel_pos_x, only_rel_pos_y = idml_package.get_elem_point_position(only_elem, 0)
         only_transform_x, only_transform_y = idml_package.get_elem_translation(only_elem)
@@ -670,18 +675,20 @@ class IDMLPackage(zipfile.ZipFile):
     def _add_spread_elements_from_idml(self, idml_package, at, only, translation):
         """ Append idml_package spread elements into self.spread[0] <Spread> node. """
 
-        # There should be only one spread in the idml_package.
-        spread_src = idml_package.spreads_objects[0]
         spread_dest_filename = self.get_spread_by_xpath(at)
         spread_dest = Spread(self, spread_dest_filename, self.working_copy_path)
         spread_dest_elt = spread_dest.dom.xpath("./Spread")[0]
 
-        for child in spread_src.dom.xpath("./Spread")[0].iterchildren():
-            if child.tag in ["Page", "FlattenerPreference"]:
+        for node in idml_package.xml_structure.xpath(only)[0].iter():
+            if node.get("XMLContent") is None:
                 continue
-            child_copy = copy.deepcopy(child)
-            self.apply_translation_to_element(child_copy, translation)
-            spread_dest_elt.append(child_copy)
+            spread_elt = idml_package.get_spread_elem_by_id(node.get("XMLContent"))
+            # Image and EPS element are included in a Rectangle.
+            if spread_elt.tag in ["Image", "EPS"]:
+                spread_elt = spread_elt.getparent()
+            spread_elt_copy = copy.deepcopy(spread_elt)
+            self.apply_translation_to_element(spread_elt_copy, translation)
+            spread_dest_elt.append(spread_elt_copy)
         spread_dest.synchronize()
         self.init_lazy_references()
 
@@ -842,18 +849,43 @@ class IDMLPackage(zipfile.ZipFile):
         return new_spread
 
     def get_spread_object_by_xpath(self, xpath):
+        elt_id = self.xml_structure.xpath(xpath)[0].get("XMLContent")
+        return self.get_spread_object_by_id(elt_id)
+
+    def get_spread_object_by_id(self, elt_id):
+        """elt_id is the `XMLContent' attribute value in the xml_structure (Stories).
+
+        Spread element matches Story one with the ParentStory or the Self attribute value."""
+
         result = None
-        ref = self.xml_structure.xpath(xpath)[0].get("XMLContent")
         for spread in self.spreads_objects:
             if (
-                spread.get_element_by_id(ref, tag="*") is not None or
-                spread.get_element_by_id(ref, tag="*", attr="ParentStory") is not None
+                spread.get_element_by_id(elt_id, tag="*") is not None or
+                spread.get_element_by_id(elt_id, tag="*", attr="ParentStory") is not None
             ):
                 result = spread
+            # FIXME: That's ugly. return spread here ?
             if result:
                 break
         return result
 
+    def get_spread_elem_by_xpath(self, xpath):
+        """Return the spread etree.Element matching the xml_structure's xpath. """
+        spread = self.get_spread_object_by_xpath(xpath)
+        elt_id = self.xml_structure.xpath(xpath)[0].get("XMLContent")
+        elt = spread.get_element_by_id(elt_id, tag="*")
+        if elt is None:
+            elt = spread.get_element_by_id(elt_id, tag="*", attr="ParentStory")
+        return elt
+
+    def get_spread_elem_by_id(self, elt_id):
+        """Return the spread etree.Element designed by XMLContent value. """
+        spread = self.get_spread_object_by_id(elt_id)
+        elt = spread.get_element_by_id(elt_id, tag="*")
+        if elt is None:
+            elt = spread.get_element_by_id(elt_id, tag="*", attr="ParentStory")
+        return elt
+
     def get_spread_by_xpath(self, xpath):
         spread = self.get_spread_object_by_xpath(xpath)
         return spread and spread.name or None
@@ -894,15 +926,6 @@ class IDMLPackage(zipfile.ZipFile):
     def get_element_content_id_by_xpath(self, xpath):
         return self.xml_structure.xpath(xpath)[0].get("XMLContent")
 
-    def get_spread_elem_by_xpath(self, xpath):
-        """Return the spread etree.Element designed by XMLElement xpath. """
-        spread = self.get_spread_object_by_xpath(xpath)
-        elt_id = self.xml_structure.xpath(xpath)[0].get("XMLContent")
-        elt = spread.get_element_by_id(elt_id, tag="*")
-        if elt is None:
-            elt = spread.get_element_by_id(elt_id, tag="*", attr="ParentStory")
-        return elt
-
     def get_elem_point_position(self, elem, point_index=0):
         point = elem.xpath("Properties/PathGeometry/GeometryPathType/PathPointArray/PathPointType")[point_index]
         x, y = point.get("Anchor").split(" ")
